#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage           : http://gsmartcontrol.berlios.de/home/index.php/en/Home
# source location    : http://download.berlios.de/gsmartcontrol/gsmartcontrol-0.8.5.tar.bz2
# last revised       : 2.10.2009
# dep                : 

softname='gsmartcontrol'
softversion='0.8.5'
packageversion='1fb'

arch='i486'
cpu='i686'

prefix=/usr

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.bz2"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://download.berlios.de/gsmartcontrol/$softname-$softversion.tar.bz2

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
             |-----handy-ruler------------------------------------------------------|
gsmartcontrol: gsmartcontrol (A graphical user interface to smartctl)
gsmartcontrol:
gsmartcontrol: GSmartcontrol is a graphical user interface for smartctl (from the
gsmartcontrol: smartmontools package), a tool for querying and controlling SMART
gsmartcontrol: data on modern hard disk drives. It allows inspection of a HDD's
gsmartcontrol: data to determin its health as well as run various tests on it.
gsmartcontrol: 
gsmartcontrol: Note: Only ATA drives are currently supported
gsmartcontrol: 
gsmartcontrol: 
gsmartcontrol: 
EOF

# check if source is present
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xjvf $srcpkg
cd $src	

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
  
./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

make
make install DESTDIR=$dest
 
# make the .desktop file
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Type=Application
Encoding=UTF-8
Name=GSmartControl
Exec=gksu /usr/bin/gsmartcontrol
Comment=Monitor and control SMART data on hard disks
Icon=gsmartcontrol
Terminal=false
Categories=Application;System;Settings;
EOF

# make the .desktop file
rm -f $dest/usr/share/applications/gsmartcontrol_gnome.desktop
rm -f $dest/usr/share/applications/gsmartcontrol_kde.desktop
rm -f $dest/usr/share/applications/gsmartcontrol_other.desktop

# add 'default' files
	cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING ChangeLog INSTALL NEWS *.txt TODO\
      $dest/usr/doc/$softname-$softversion
	
#  strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# SalixBuild
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "atk,cairo,cairomm,cxxlibs|gcc-g++,expat,fontconfig,freetype,\
gcc,glib2,glibmm,gtk+2,gtkmm,libX11,libXau,libXcomposite,libXcursor,\
libXdamage,libXdmcp,libXext,libXfixes,libXi,libXinerama,libXrandr,\
libXrender,libpng,libsigc++,libxcb,pango,pangomm,pcre,pixman,zlib" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/divers/salix/xap/gsmartcontrol/build-gsmartcontrol.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
